Algorithm

Struct Algorithm 

pub struct Algorithm(/* private fields */);
Represents a specific AEAD algorithm.

Implementations

Source

impl Algorithm

pub const unsafe fn from_ptr(ptr: *const EVP_AEAD) -> Self

Creates an Algorithm from a raw BoringSSL pointer.

Safety

The caller must ensure that ptr is a valid pointer to an EVP_AEAD with a 'static lifetime.

pub fn aes_128_gcm() -> Self

AES-128 in Galois Counter Mode (GCM).

This corresponds to EVP_aead_aes_128_gcm.

pub fn aes_256_gcm() -> Self

AES-256 in Galois Counter Mode (GCM).

This corresponds to EVP_aead_aes_256_gcm.

pub fn chacha20_poly1305() -> Self

ChaCha20-Poly1305 as described in RFC 8439.

This corresponds to EVP_aead_chacha20_poly1305.

pub fn xchacha20_poly1305() -> Self

XChaCha20-Poly1305 with a 24-byte nonce.

This corresponds to EVP_aead_xchacha20_poly1305.

pub fn key_length(&self) -> usize

Returns the key length, in bytes, required by this algorithm.

This corresponds to EVP_AEAD_key_length.

pub fn max_overhead(&self) -> usize

Returns the maximum additional bytes produced when sealing.

This corresponds to EVP_AEAD_max_overhead.

pub fn max_tag_len(&self) -> usize

Returns the maximum tag length for this algorithm.

This corresponds to EVP_AEAD_max_tag_len.

pub fn nonce_len(&self) -> usize

Returns the nonce length, in bytes, required by this algorithm.

This corresponds to EVP_AEAD_nonce_length.

pub const fn as_ptr(&self) -> *const EVP_AEAD

Returns the raw EVP_AEAD pointer.